# TPK4186 - Advanced Tools for Performance Engineering
# Main.py
# by Antoine Rauzy
# Copyrights (c) 2019-2020 NTNU
#
# This file is part of the educational material provided to NTNU students registered to the course TPK4186.
# This work is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License.
# For details about this license, see https://creativecommons.org/licenses/by-nc/4.0/.

# Table of Contents
# -----------------
# 1. Required modules
# 2. Application

# 1. Required modules
# -------------------

from PERT import *
from TSVInterface import *
import numpy as np
import matplotlib.pyplot as plt

# 2. Application
# --------------

project = Project()
parser = TSVParser()
printer = TSVPrinter()
fileName= "Project.csv"

errors = parser.ImportProjectAtTSVFormat(project, fileName)
if errors!=0:
  sys.exit()
# printer.ExportProjectAtTSVFormat(project, "ProjectCopy.csv")

numberOfSimulations = 10000
projectDurations = project.PerformSimulations(numberOfSimulations)

print("Actities\t#Critical\tProportion")
for activity in project.GetActivities():
  print("{0:s}\t{1:d}\t{2:.2f}".format(activity.GetCode(), activity.GetCriticalCount(), activity.GetCriticalCount()/numberOfSimulations))

print("\nProject duration")
print("Min\t{0:.0f}".format(projectDurations.min()))
print("Max\t{0:.0f}".format(projectDurations.max()))
print("Mean\t{0:.2f}".format(projectDurations.mean()))
print("Stddev\t{0:.2f}".format(projectDurations.std()))

plt.hist(projectDurations, bins=np.arange(projectDurations.min(), projectDurations.max()+1), density=True)
plt.xlabel('Duration')
plt.ylabel('Proportion')
plt.title('Project duration distribution ({0:d} simulations)'.format(numberOfSimulations))
plt.show()


