# TPK4186 - Advanced Tools for Performance Engineering
# Case study: Sales Analysis
# by Antoine Rauzy
# This work is licensed under a Creative Commons Attribution-ShareAlike 4.0 International License
# https://creativecommons.org/licenses/by-sa/4.0/

# Table of contents
# -----------------
# 1) Imported modules
# 2) Products
# 3) Shop
#   3.1) Products
#   3.2) Import XLSX spreadsheet
# 4) Main

# 1) Imported modules
# -------------------

import sys
import string
import math
import random
import calendar
import openpyxl

# 2) Products
# --------

class Product:
  def __init__(self, reference):
    self.reference = reference
    self.profitPerSale = 1
    self.monthlySales = [0 for month in range(0, 13)]


# 3) Shop
# -------

class Shop:
  def __init__(self):
    self.products = dict()

# 3.1) Products
# ~~~~~~~~~~~~~

  def NewProduct(self, reference):
    product = Product(reference)
    self.products[reference] = product
    return product

# 3.2) Import XSPL spreadsheet
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  def ImportXLSXSpreadsheet(self, fileName):
    workbook = openpyxl.load_workbook(fileName)
    worksheet = workbook.active
    self.DownloadXLSXWorksheet(worksheet)
    return 0

  def DownloadXLSXWorksheet(self, worksheet):
    row = 2
    while True:
      reference = worksheet['A%d' % row].value
      if reference==None:
        break
      print(reference)
      product = self.NewProduct(reference)
      product.profitPerSale = worksheet['B%d' % row].value
      for month in range(1, 13):
        product.monthlySales[month] = worksheet['%s%d' % (chr(ord('B')+month), row)].value
      row += 1

# 3.3) Export XLSX spreadsheet
# ~~~~~~~~~~~~~~~~~~~~~~~~~~

  def ExportXLSXSpreadsheet(self, fileName):
    workbook = openpyxl.Workbook()
    worksheet = workbook.active
    self.UploadXLSXWorksheet(worksheet)
    workbook.save(fileName)
    return 0

  def UploadXLSXWorksheet(self, worksheet):
    worksheet['A1'] = "Product"
    worksheet['B1'] = "Profit"
    for month in range(1, 13):
      worksheet['%s1' % chr(ord('B')+month)] = calendar.month_abbr[month]
    count = 2
    for product in self.products.values():
      worksheet['A%d' % count] = product.reference
      worksheet['B%d' % count] = str(product.profitPerSale)
      for month in range(1, 13):
        worksheet['%s%d' % (chr(ord('B')+month), count)] = product.monthlySales[month]
      count += 1

# 4) Main
# --------

shop = Shop()

shop.ImportXLSXSpreadsheet("sales.xlsx")
shop.ExportXLSXSpreadsheet("sales2.xlsx")

