# TPK4186 - Advanced Tools for Performance Engineering
# WealthDistribution.py
# by Antoine Rauzy
# Copyrights (c) 2019-2020 NTNU
#
# This file is part of the educational material provided to NTNU students registered to the course TPK4186.
# It is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License.
# For details about this license, see https://creativecommons.org/licenses/by-nc/4.0/.

import sys
import math
import numpy as np
import matplotlib.pyplot as plt

def LoadSampleFromCSVFile(fileName, delimiter):
  try:
    distribution = np.genfromtxt(fileName, delimiter=delimiter)
  except:
    sys.stderr.write("Unable to open file " + fileName + "\n")
    return None
  return distribution

wealthSample = LoadSampleFromCSVFile("Norway2018.csv", "\t")
wealths = wealthSample[:, 1]
mean = wealths.mean()
stddev = wealths.std()
errfac90 = 1.64*stddev/math.sqrt(wealths.size)
errfac95 = 1.96*stddev/math.sqrt(wealths.size)
errfac99 = 2.58*stddev/math.sqrt(wealths.size)
print("mean   \t{0:.0f}".format(mean))
print("stddev \t{0:.0f}".format(stddev))
print("90% rng\t{0:.0f}\t{1:.0f}".format(mean-errfac90, mean+errfac90))
print("95% rng\t{0:.0f}\t{1:.0f}".format(mean-errfac95, mean+errfac95))
print("99% rng\t{0:.0f}\t{1:.0f}".format(mean-errfac99, mean+errfac99))

min = np.amin(wealths)
max = np.amax(wealths)
print(min)
print(max)
step = (max-min)/10
bins = np.arange(min, max+1, step)
histogram, bins = np.histogram(wealths, bins = bins)
print(histogram)

step = (max-min)/20
bins = np.arange(min, max+1, step)
histogram, bins = np.histogram(wealths, bins = bins)
print(histogram)

bins = [0.01, 0.05, 0.1, 0.33, 0.5, 0.66, 0.9, 0.95, 0.99]
quantiles = np.quantile(wealths, bins)
print(quantiles)

plt.plot(bins, quantiles)

plt.title('Net wealth distribution of Norwegian families')
plt.ylabel('Net wealth')
plt.xlabel('Quantiles')
plt.legend()
plt.savefig('NetWealth.pdf')  
plt.show()

